@@ -37,6 +37,12 @@ class Users(_defaults_.Defaults):
 		defaults=None,
 	):	
 
+		# docs.
+		Docs.__init__(self,
+			initialized=True,
+			module="website.users", 
+			notes=[], )
+
 		# defaults.
 		_defaults_.Defaults.__init__(self, traceback="w3bsite.Website.users",)
 		self.assign(defaults.dict())
