@@ -21,6 +21,12 @@ class VPS(_defaults_.Defaults):
 
 	):	
 
+		# docs.
+		Docs.__init__(self,
+			initialized=True,
+			module="website.vps", 
+			notes=[], )
+
 		# defaults.
 		_defaults_.Defaults.__init__(self, traceback="w3bsite.Website.vps",)
 		self.assign(defaults.dict())
